@@ -59,7 +59,7 @@ def loop_fn(model, optimizer, loss_fn, trainset, valset, batch_size, max_patienc
 
     for epoch in range(MAX_EPOCH):
         train_fn(train_loader, model, optimizer, loss_fn, scaler, DEVICE)
-        loss = check_loss(val_loader, model, loss_fn, device=DEVICE)
+        loss = check_loss(val_loader, model, DEVICE, epoch)
         # early stop
         if loss < min_loss:
             save_checkpoint(model, optimizer, file_name=f'{model_name}.pth.tar')
